@@ -1,13 +1,13 @@
-from django.test import TestCase
-from .. import TEST_FILES_DIR
-from .. import TEST_IMAGES_DIR
-from .util import open_file
 import glob
 import os
 import random
 
 from django.core.management.utils import get_random_secret_key
+from test_plus.test import TestCase
+
+from .. import TEST_FILES_DIR, TEST_IMAGES_DIR
 from ..models import TestEncryptedFileFieldModel, TestEncryptedImageFieldModel
+from .util import open_file
 
 
 class TestEncryptedFileField(TestCase):
