@@ -1,10 +1,10 @@
-from django.test import TestCase
-
-import random
 import os
-from django.core.management.utils import get_random_secret_key
-from ..models import TestEncryptedJSONField
+import random
 from datetime import datetime
+
+from django.core.management.utils import get_random_secret_key
+from test_plus.test import TestCase
+
 from ..models import TestEncryptedJSONField
 
 
